@@ -26,14 +26,19 @@
 
 
 /// Rellena con datos los QTextEdit y muestra el formulario.
-AboutView::AboutView(QDialog *parent) : QDialog(parent) {
+/**
+\param parent
+**/
+AboutView::AboutView ( QDialog *parent ) : QDialog ( parent )
+{
     QString str_sobre;
     QString str_autores;
     QString str_soporte;
     QString str_licencia;
-    setupUi(this);
+    setupUi ( this );
+    centrarEnPantalla(this);
 
-    mui_lbversion->setText(mui_lbversion->text() + " " + tr("Compilado usando la version de QT:") + " " + QT_VERSION_STR);
+    mui_lbversion->setText ( mui_lbversion->text() + " " +   trUtf8 ( "Compilado usando la version de QT:" ) + " " + QT_VERSION_STR );
 
     str_sobre = "<br /><br /><br /><br /><center><h2>Facturaci&oacute;n GPL</h2></center>";
     str_autores = "<center><h2>Autores de BulmaFact</h2>" \
@@ -41,7 +46,12 @@ AboutView::AboutView(QDialog *parent) : QDialog(parent) {
                   "Programaci&oacute;n:<br/> " \
                   "<b>Tomeu Borr&aacute;s.</b>&nbsp;<a href=\"mailto:tborras@conetxia.com\">tborras@conetxia.com</a><br/>" \
                   "<b>Fco. Javier M. C. </b>&nbsp;<a href=\"mailto:fcojavmc@todo-redes.com\">fcojavmc@todo-redes.com</a><br/>" \
+                  "<b>Leopold Palomo </b>&nbsp;<a href=\"mailto:leo@alaxarxa.net\">leo@alaxarxa.net</a><br/>" \
+                  "<b>Jean Ren&eacute; M&egrave;rou</b><br />" \
+                  "<b>Miguel Gea</b>&nbsp;<a href=\"mailto:xerakko@debian.org\">xerakko@debian.org</a><br/>" \
                   "</p><p>" \
+
+
                   "Depuracion y manuales:<br/>" \
                   "<b>Cristina Marco.</b>&nbsp;<a href=\"cmarco@conetxia.com\">cmarco@conetxia.com</a>" \
                   "</p></center>";
@@ -401,13 +411,16 @@ AboutView::AboutView(QDialog *parent) : QDialog(parent) {
                    "<P> " \
                    "<H2>END OF TERMS AND CONDITIONS</H2>";
 
-    textEdit_sobre->setHtml(str_sobre);
-    textEdit_autores->setHtml(str_autores);
-    textEdit_soporte->setHtml(str_soporte);
-    textEdit_licencia->setHtml(str_licencia);
+    textEdit_sobre->setHtml ( str_sobre );
+    textEdit_autores->setHtml ( str_autores );
+    textEdit_soporte->setHtml ( str_soporte );
+    textEdit_licencia->setHtml ( str_licencia );
 }
 
 
 /// Destructor de la clase
-AboutView::~AboutView() {}
+/**
+**/
+AboutView::~AboutView()
+{}
 
